C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LDM_GET_ALPHA    **
C**************************
C
C
CD-Doc:
C ALPHa            SUBROUTINE LDM_GET_ALPHA (VALUE, IFLAG, ND)
CD-end
      SUBROUTINE LDM_GET_ALPHA (VALUE, IFLAG, ND)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Get value of real parameter ALPHA
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      REAL VALUE
      INTEGER IFLAG
      INTEGER ND

C  VALUE     (W)   Returns the cell parameter alpha in degrees
C  IFLAG     (W)   Flag = -1 undefined value
C                       =  0 default value
C                       =  1 value set explicitly
C                       =  2 value set globally
C ND         (W)   No. of decimal places for printing (- if E format)
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
      VALUE = ALPHA
      IFLAG = IS_ALPHA
      ND = ND_ALPHA
      IF (ND.EQ.-1000) ND = 3
      RETURN
      END
